# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DrgAttachment(object):
    """
    A DRG attachment serves as a link between a DRG and a network resource. A DRG can be attached to a VCN,
    IPSec tunnel, remote peering connection, or virtual circuit.

    For more information, see `Overview of the Networking Service`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/overview.htm
    """

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "ATTACHING"
    LIFECYCLE_STATE_ATTACHING = "ATTACHING"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "ATTACHED"
    LIFECYCLE_STATE_ATTACHED = "ATTACHED"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "DETACHING"
    LIFECYCLE_STATE_DETACHING = "DETACHING"

    #: A constant which can be used with the lifecycle_state property of a DrgAttachment.
    #: This constant has a value of "DETACHED"
    LIFECYCLE_STATE_DETACHED = "DETACHED"

    def __init__(self, **kwargs):
        """
        Initializes a new DrgAttachment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this DrgAttachment.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this DrgAttachment.
        :type display_name: str

        :param drg_id:
            The value to assign to the drg_id property of this DrgAttachment.
        :type drg_id: str

        :param id:
            The value to assign to the id property of this DrgAttachment.
        :type id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DrgAttachment.
            Allowed values for this property are: "ATTACHING", "ATTACHED", "DETACHING", "DETACHED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this DrgAttachment.
        :type time_created: datetime

        :param drg_route_table_id:
            The value to assign to the drg_route_table_id property of this DrgAttachment.
        :type drg_route_table_id: str

        :param network_details:
            The value to assign to the network_details property of this DrgAttachment.
        :type network_details: oci.core.models.DrgAttachmentNetworkDetails

        :param defined_tags:
            The value to assign to the defined_tags property of this DrgAttachment.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DrgAttachment.
        :type freeform_tags: dict(str, str)

        :param route_table_id:
            The value to assign to the route_table_id property of this DrgAttachment.
        :type route_table_id: str

        :param vcn_id:
            The value to assign to the vcn_id property of this DrgAttachment.
        :type vcn_id: str

        :param export_drg_route_distribution_id:
            The value to assign to the export_drg_route_distribution_id property of this DrgAttachment.
        :type export_drg_route_distribution_id: str

        :param is_cross_tenancy:
            The value to assign to the is_cross_tenancy property of this DrgAttachment.
        :type is_cross_tenancy: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'drg_id': 'str',
            'id': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'drg_route_table_id': 'str',
            'network_details': 'DrgAttachmentNetworkDetails',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'route_table_id': 'str',
            'vcn_id': 'str',
            'export_drg_route_distribution_id': 'str',
            'is_cross_tenancy': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'drg_id': 'drgId',
            'id': 'id',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'drg_route_table_id': 'drgRouteTableId',
            'network_details': 'networkDetails',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'route_table_id': 'routeTableId',
            'vcn_id': 'vcnId',
            'export_drg_route_distribution_id': 'exportDrgRouteDistributionId',
            'is_cross_tenancy': 'isCrossTenancy'
        }

        self._compartment_id = None
        self._display_name = None
        self._drg_id = None
        self._id = None
        self._lifecycle_state = None
        self._time_created = None
        self._drg_route_table_id = None
        self._network_details = None
        self._defined_tags = None
        self._freeform_tags = None
        self._route_table_id = None
        self._vcn_id = None
        self._export_drg_route_distribution_id = None
        self._is_cross_tenancy = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this DrgAttachment.
        The `OCID`__ of the compartment containing the DRG attachment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DrgAttachment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DrgAttachment.
        The `OCID`__ of the compartment containing the DRG attachment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DrgAttachment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this DrgAttachment.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this DrgAttachment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this DrgAttachment.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this DrgAttachment.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_id(self):
        """
        **[Required]** Gets the drg_id of this DrgAttachment.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The drg_id of this DrgAttachment.
        :rtype: str
        """
        return self._drg_id

    @drg_id.setter
    def drg_id(self, drg_id):
        """
        Sets the drg_id of this DrgAttachment.
        The `OCID`__ of the DRG.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param drg_id: The drg_id of this DrgAttachment.
        :type: str
        """
        self._drg_id = drg_id

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DrgAttachment.
        The DRG attachment's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this DrgAttachment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DrgAttachment.
        The DRG attachment's Oracle ID (`OCID`__).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this DrgAttachment.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this DrgAttachment.
        The DRG attachment's current state.

        Allowed values for this property are: "ATTACHING", "ATTACHED", "DETACHING", "DETACHED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DrgAttachment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DrgAttachment.
        The DRG attachment's current state.


        :param lifecycle_state: The lifecycle_state of this DrgAttachment.
        :type: str
        """
        allowed_values = ["ATTACHING", "ATTACHED", "DETACHING", "DETACHED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this DrgAttachment.
        The date and time the DRG attachment was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this DrgAttachment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DrgAttachment.
        The date and time the DRG attachment was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this DrgAttachment.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def drg_route_table_id(self):
        """
        Gets the drg_route_table_id of this DrgAttachment.
        The `OCID`__ of the DRG route table that is assigned to this attachment.

        The DRG route table manages traffic inside the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The drg_route_table_id of this DrgAttachment.
        :rtype: str
        """
        return self._drg_route_table_id

    @drg_route_table_id.setter
    def drg_route_table_id(self, drg_route_table_id):
        """
        Sets the drg_route_table_id of this DrgAttachment.
        The `OCID`__ of the DRG route table that is assigned to this attachment.

        The DRG route table manages traffic inside the DRG.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param drg_route_table_id: The drg_route_table_id of this DrgAttachment.
        :type: str
        """
        self._drg_route_table_id = drg_route_table_id

    @property
    def network_details(self):
        """
        Gets the network_details of this DrgAttachment.

        :return: The network_details of this DrgAttachment.
        :rtype: oci.core.models.DrgAttachmentNetworkDetails
        """
        return self._network_details

    @network_details.setter
    def network_details(self, network_details):
        """
        Sets the network_details of this DrgAttachment.

        :param network_details: The network_details of this DrgAttachment.
        :type: oci.core.models.DrgAttachmentNetworkDetails
        """
        self._network_details = network_details

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DrgAttachment.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this DrgAttachment.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DrgAttachment.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this DrgAttachment.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DrgAttachment.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this DrgAttachment.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DrgAttachment.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this DrgAttachment.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this DrgAttachment.
        The OCID of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        This field is deprecated. Instead, use the `networkDetails` field to view the `OCID`__ of the attached resource.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm
        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The route_table_id of this DrgAttachment.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this DrgAttachment.
        The OCID of the route table the DRG attachment is using.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        This field is deprecated. Instead, use the `networkDetails` field to view the `OCID`__ of the attached resource.

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm
        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param route_table_id: The route_table_id of this DrgAttachment.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this DrgAttachment.
        The `OCID`__ of the VCN.
        This field is deprecated. Instead, use the `networkDetails` field to view the `OCID`__ of the attached resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this DrgAttachment.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this DrgAttachment.
        The `OCID`__ of the VCN.
        This field is deprecated. Instead, use the `networkDetails` field to view the `OCID`__ of the attached resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this DrgAttachment.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def export_drg_route_distribution_id(self):
        """
        Gets the export_drg_route_distribution_id of this DrgAttachment.
        The `OCID`__ of the export route distribution used to specify how routes in the assigned DRG route table
        are advertised to the attachment.
        If this value is null, no routes are advertised through this attachment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The export_drg_route_distribution_id of this DrgAttachment.
        :rtype: str
        """
        return self._export_drg_route_distribution_id

    @export_drg_route_distribution_id.setter
    def export_drg_route_distribution_id(self, export_drg_route_distribution_id):
        """
        Sets the export_drg_route_distribution_id of this DrgAttachment.
        The `OCID`__ of the export route distribution used to specify how routes in the assigned DRG route table
        are advertised to the attachment.
        If this value is null, no routes are advertised through this attachment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param export_drg_route_distribution_id: The export_drg_route_distribution_id of this DrgAttachment.
        :type: str
        """
        self._export_drg_route_distribution_id = export_drg_route_distribution_id

    @property
    def is_cross_tenancy(self):
        """
        Gets the is_cross_tenancy of this DrgAttachment.
        Indicates whether the DRG attachment and attached network live in a different tenancy than the DRG.

        Example: `false`


        :return: The is_cross_tenancy of this DrgAttachment.
        :rtype: bool
        """
        return self._is_cross_tenancy

    @is_cross_tenancy.setter
    def is_cross_tenancy(self, is_cross_tenancy):
        """
        Sets the is_cross_tenancy of this DrgAttachment.
        Indicates whether the DRG attachment and attached network live in a different tenancy than the DRG.

        Example: `false`


        :param is_cross_tenancy: The is_cross_tenancy of this DrgAttachment.
        :type: bool
        """
        self._is_cross_tenancy = is_cross_tenancy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalingConfiguration(object):
    """
    An autoscaling configuration lets you dynamically scale the resources in a Compute instance pool.
    For more information, see `Autoscaling`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/autoscalinginstancepools.htm
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalingConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this AutoScalingConfiguration.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this AutoScalingConfiguration.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this AutoScalingConfiguration.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AutoScalingConfiguration.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this AutoScalingConfiguration.
        :type id: str

        :param cool_down_in_seconds:
            The value to assign to the cool_down_in_seconds property of this AutoScalingConfiguration.
        :type cool_down_in_seconds: int

        :param is_enabled:
            The value to assign to the is_enabled property of this AutoScalingConfiguration.
        :type is_enabled: bool

        :param resource:
            The value to assign to the resource property of this AutoScalingConfiguration.
        :type resource: oci.autoscaling.models.Resource

        :param policies:
            The value to assign to the policies property of this AutoScalingConfiguration.
        :type policies: list[oci.autoscaling.models.AutoScalingPolicy]

        :param time_created:
            The value to assign to the time_created property of this AutoScalingConfiguration.
        :type time_created: datetime

        :param max_resource_count:
            The value to assign to the max_resource_count property of this AutoScalingConfiguration.
        :type max_resource_count: int

        :param min_resource_count:
            The value to assign to the min_resource_count property of this AutoScalingConfiguration.
        :type min_resource_count: int

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'cool_down_in_seconds': 'int',
            'is_enabled': 'bool',
            'resource': 'Resource',
            'policies': 'list[AutoScalingPolicy]',
            'time_created': 'datetime',
            'max_resource_count': 'int',
            'min_resource_count': 'int'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'cool_down_in_seconds': 'coolDownInSeconds',
            'is_enabled': 'isEnabled',
            'resource': 'resource',
            'policies': 'policies',
            'time_created': 'timeCreated',
            'max_resource_count': 'maxResourceCount',
            'min_resource_count': 'minResourceCount'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._cool_down_in_seconds = None
        self._is_enabled = None
        self._resource = None
        self._policies = None
        self._time_created = None
        self._max_resource_count = None
        self._min_resource_count = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AutoScalingConfiguration.
        The `OCID`__ of the compartment containing the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AutoScalingConfiguration.
        The `OCID`__ of the compartment containing the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this AutoScalingConfiguration.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AutoScalingConfiguration.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AutoScalingConfiguration.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AutoScalingConfiguration.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AutoScalingConfiguration.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this AutoScalingConfiguration.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AutoScalingConfiguration.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this AutoScalingConfiguration.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AutoScalingConfiguration.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AutoScalingConfiguration.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AutoScalingConfiguration.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AutoScalingConfiguration.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutoScalingConfiguration.
        The `OCID`__ of the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this AutoScalingConfiguration.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutoScalingConfiguration.
        The `OCID`__ of the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this AutoScalingConfiguration.
        :type: str
        """
        self._id = id

    @property
    def cool_down_in_seconds(self):
        """
        Gets the cool_down_in_seconds of this AutoScalingConfiguration.
        For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions.
        The cooldown period gives the system time to stabilize before rescaling. The minimum value is 300 seconds, which
        is also the default. The cooldown period starts when the instance pool reaches the running state.

        For schedule-based autoscaling policies, this value is not used.


        :return: The cool_down_in_seconds of this AutoScalingConfiguration.
        :rtype: int
        """
        return self._cool_down_in_seconds

    @cool_down_in_seconds.setter
    def cool_down_in_seconds(self, cool_down_in_seconds):
        """
        Sets the cool_down_in_seconds of this AutoScalingConfiguration.
        For threshold-based autoscaling policies, this value is the minimum period of time to wait between scaling actions.
        The cooldown period gives the system time to stabilize before rescaling. The minimum value is 300 seconds, which
        is also the default. The cooldown period starts when the instance pool reaches the running state.

        For schedule-based autoscaling policies, this value is not used.


        :param cool_down_in_seconds: The cool_down_in_seconds of this AutoScalingConfiguration.
        :type: int
        """
        self._cool_down_in_seconds = cool_down_in_seconds

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this AutoScalingConfiguration.
        Whether the autoscaling configuration is enabled.


        :return: The is_enabled of this AutoScalingConfiguration.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this AutoScalingConfiguration.
        Whether the autoscaling configuration is enabled.


        :param is_enabled: The is_enabled of this AutoScalingConfiguration.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def resource(self):
        """
        **[Required]** Gets the resource of this AutoScalingConfiguration.

        :return: The resource of this AutoScalingConfiguration.
        :rtype: oci.autoscaling.models.Resource
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """
        Sets the resource of this AutoScalingConfiguration.

        :param resource: The resource of this AutoScalingConfiguration.
        :type: oci.autoscaling.models.Resource
        """
        self._resource = resource

    @property
    def policies(self):
        """
        **[Required]** Gets the policies of this AutoScalingConfiguration.
        Autoscaling policy definitions for the autoscaling configuration. An autoscaling policy defines the criteria that
        trigger autoscaling actions and the actions to take.


        :return: The policies of this AutoScalingConfiguration.
        :rtype: list[oci.autoscaling.models.AutoScalingPolicy]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """
        Sets the policies of this AutoScalingConfiguration.
        Autoscaling policy definitions for the autoscaling configuration. An autoscaling policy defines the criteria that
        trigger autoscaling actions and the actions to take.


        :param policies: The policies of this AutoScalingConfiguration.
        :type: list[oci.autoscaling.models.AutoScalingPolicy]
        """
        self._policies = policies

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AutoScalingConfiguration.
        The date and time the autoscaling configuration was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this AutoScalingConfiguration.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AutoScalingConfiguration.
        The date and time the autoscaling configuration was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this AutoScalingConfiguration.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def max_resource_count(self):
        """
        Gets the max_resource_count of this AutoScalingConfiguration.
        The maximum number of resources to scale out to.


        :return: The max_resource_count of this AutoScalingConfiguration.
        :rtype: int
        """
        return self._max_resource_count

    @max_resource_count.setter
    def max_resource_count(self, max_resource_count):
        """
        Sets the max_resource_count of this AutoScalingConfiguration.
        The maximum number of resources to scale out to.


        :param max_resource_count: The max_resource_count of this AutoScalingConfiguration.
        :type: int
        """
        self._max_resource_count = max_resource_count

    @property
    def min_resource_count(self):
        """
        Gets the min_resource_count of this AutoScalingConfiguration.
        The minimum number of resources to scale in to.


        :return: The min_resource_count of this AutoScalingConfiguration.
        :rtype: int
        """
        return self._min_resource_count

    @min_resource_count.setter
    def min_resource_count(self, min_resource_count):
        """
        Sets the min_resource_count of this AutoScalingConfiguration.
        The minimum number of resources to scale in to.


        :param min_resource_count: The min_resource_count of this AutoScalingConfiguration.
        :type: int
        """
        self._min_resource_count = min_resource_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OperatorAction(object):
    """
    Details of the operator action. Operator actions are a pre-defined set of commands available to the operator on different layers of the infrastructure. Although the groupings may differ depending on the infrastructure layers,
    the groups are designed to enable the operator access to commands to resolve a specific set of issues. The infrastructure layers controlled by the Operator Control include Dom0, CellServer, and Control Plane Server (CPS).

    There are five groups available to the operator. x-obmcs-top-level-enum: '#/definitions/OperatorActionCategories' enum: *OPERATORACTIONCATEGORIES

    The following infrastructure layers are controlled by the operator actions x-obmcs-top-level-enum: '#/definitions/InfrastructureLayers' enum: *INFRASTRUCTURELAYERS
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OperatorAction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this OperatorAction.
        :type id: str

        :param name:
            The value to assign to the name property of this OperatorAction.
        :type name: str

        :param component:
            The value to assign to the component property of this OperatorAction.
        :type component: str

        :param description:
            The value to assign to the description property of this OperatorAction.
        :type description: str

        :param properties:
            The value to assign to the properties property of this OperatorAction.
        :type properties: list[oci.operator_access_control.models.OperatorActionProperties]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'component': 'str',
            'description': 'str',
            'properties': 'list[OperatorActionProperties]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'component': 'component',
            'description': 'description',
            'properties': 'properties'
        }

        self._id = None
        self._name = None
        self._component = None
        self._description = None
        self._properties = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this OperatorAction.
        Unique Oracle assigned identifier for the operator action.


        :return: The id of this OperatorAction.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OperatorAction.
        Unique Oracle assigned identifier for the operator action.


        :param id: The id of this OperatorAction.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this OperatorAction.
        Name of the operator action.


        :return: The name of this OperatorAction.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OperatorAction.
        Name of the operator action.


        :param name: The name of this OperatorAction.
        :type: str
        """
        self._name = name

    @property
    def component(self):
        """
        Gets the component of this OperatorAction.
        Name of the infrastructure layer associated with the operator action.


        :return: The component of this OperatorAction.
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """
        Sets the component of this OperatorAction.
        Name of the infrastructure layer associated with the operator action.


        :param component: The component of this OperatorAction.
        :type: str
        """
        self._component = component

    @property
    def description(self):
        """
        Gets the description of this OperatorAction.
        Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made
        available to the operator under this operator action.


        :return: The description of this OperatorAction.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OperatorAction.
        Description of the operator action in terms of associated risk profile, and characteristics of the operating system commands made
        available to the operator under this operator action.


        :param description: The description of this OperatorAction.
        :type: str
        """
        self._description = description

    @property
    def properties(self):
        """
        Gets the properties of this OperatorAction.
        Fine grained properties associated with the operator control.


        :return: The properties of this OperatorAction.
        :rtype: list[oci.operator_access_control.models.OperatorActionProperties]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this OperatorAction.
        Fine grained properties associated with the operator control.


        :param properties: The properties of this OperatorAction.
        :type: list[oci.operator_access_control.models.OperatorActionProperties]
        """
        self._properties = properties

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TypedObject(object):
    """
    The `TypedObject` class is a base class for any model object that has a type.
    """

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "SHAPE"
    MODEL_TYPE_SHAPE = "SHAPE"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "INPUT_PORT"
    MODEL_TYPE_INPUT_PORT = "INPUT_PORT"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "SHAPE_FIELD"
    MODEL_TYPE_SHAPE_FIELD = "SHAPE_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "INPUT_FIELD"
    MODEL_TYPE_INPUT_FIELD = "INPUT_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "DERIVED_FIELD"
    MODEL_TYPE_DERIVED_FIELD = "DERIVED_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "MACRO_FIELD"
    MODEL_TYPE_MACRO_FIELD = "MACRO_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "OUTPUT_FIELD"
    MODEL_TYPE_OUTPUT_FIELD = "OUTPUT_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "DYNAMIC_PROXY_FIELD"
    MODEL_TYPE_DYNAMIC_PROXY_FIELD = "DYNAMIC_PROXY_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "OUTPUT_PORT"
    MODEL_TYPE_OUTPUT_PORT = "OUTPUT_PORT"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "DYNAMIC_INPUT_FIELD"
    MODEL_TYPE_DYNAMIC_INPUT_FIELD = "DYNAMIC_INPUT_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "PROXY_FIELD"
    MODEL_TYPE_PROXY_FIELD = "PROXY_FIELD"

    #: A constant which can be used with the model_type property of a TypedObject.
    #: This constant has a value of "PARAMETER"
    MODEL_TYPE_PARAMETER = "PARAMETER"

    def __init__(self, **kwargs):
        """
        Initializes a new TypedObject object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.OutputPort`
        * :class:`~oci.data_integration.models.DynamicInputField`
        * :class:`~oci.data_integration.models.AbstractField`
        * :class:`~oci.data_integration.models.InputField`
        * :class:`~oci.data_integration.models.Shape`
        * :class:`~oci.data_integration.models.InputPort`
        * :class:`~oci.data_integration.models.ProxyField`
        * :class:`~oci.data_integration.models.DynamicProxyField`
        * :class:`~oci.data_integration.models.ShapeField`
        * :class:`~oci.data_integration.models.Parameter`
        * :class:`~oci.data_integration.models.OutputField`
        * :class:`~oci.data_integration.models.MacroField`
        * :class:`~oci.data_integration.models.DerivedField`
        * :class:`~oci.data_integration.models.FlowPort`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this TypedObject.
            Allowed values for this property are: "SHAPE", "INPUT_PORT", "SHAPE_FIELD", "INPUT_FIELD", "DERIVED_FIELD", "MACRO_FIELD", "OUTPUT_FIELD", "DYNAMIC_PROXY_FIELD", "OUTPUT_PORT", "DYNAMIC_INPUT_FIELD", "PROXY_FIELD", "PARAMETER"
        :type model_type: str

        :param key:
            The value to assign to the key property of this TypedObject.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this TypedObject.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TypedObject.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param config_values:
            The value to assign to the config_values property of this TypedObject.
        :type config_values: oci.data_integration.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this TypedObject.
        :type object_status: int

        :param name:
            The value to assign to the name property of this TypedObject.
        :type name: str

        :param description:
            The value to assign to the description property of this TypedObject.
        :type description: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'name': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'name': 'name',
            'description': 'description'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._object_status = None
        self._name = None
        self._description = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'OUTPUT_PORT':
            return 'OutputPort'

        if type == 'DYNAMIC_INPUT_FIELD':
            return 'DynamicInputField'

        if type == 'FIELD':
            return 'AbstractField'

        if type == 'INPUT_FIELD':
            return 'InputField'

        if type == 'SHAPE':
            return 'Shape'

        if type == 'INPUT_PORT':
            return 'InputPort'

        if type == 'PROXY_FIELD':
            return 'ProxyField'

        if type == 'DYNAMIC_PROXY_FIELD':
            return 'DynamicProxyField'

        if type == 'SHAPE_FIELD':
            return 'ShapeField'

        if type == 'PARAMETER':
            return 'Parameter'

        if type == 'OUTPUT_FIELD':
            return 'OutputField'

        if type == 'MACRO_FIELD':
            return 'MacroField'

        if type == 'DERIVED_FIELD':
            return 'DerivedField'

        if type == 'FLOW_PORT':
            return 'FlowPort'
        else:
            return 'TypedObject'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this TypedObject.
        The type of the types object.

        Allowed values for this property are: "SHAPE", "INPUT_PORT", "SHAPE_FIELD", "INPUT_FIELD", "DERIVED_FIELD", "MACRO_FIELD", "OUTPUT_FIELD", "DYNAMIC_PROXY_FIELD", "OUTPUT_PORT", "DYNAMIC_INPUT_FIELD", "PROXY_FIELD", "PARAMETER"


        :return: The model_type of this TypedObject.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this TypedObject.
        The type of the types object.


        :param model_type: The model_type of this TypedObject.
        :type: str
        """
        allowed_values = ["SHAPE", "INPUT_PORT", "SHAPE_FIELD", "INPUT_FIELD", "DERIVED_FIELD", "MACRO_FIELD", "OUTPUT_FIELD", "DYNAMIC_PROXY_FIELD", "OUTPUT_PORT", "DYNAMIC_INPUT_FIELD", "PROXY_FIELD", "PARAMETER"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this TypedObject.
        The key of the object.


        :return: The key of this TypedObject.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TypedObject.
        The key of the object.


        :param key: The key of this TypedObject.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this TypedObject.
        The model version of an object.


        :return: The model_version of this TypedObject.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this TypedObject.
        The model version of an object.


        :param model_version: The model_version of this TypedObject.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this TypedObject.

        :return: The parent_ref of this TypedObject.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this TypedObject.

        :param parent_ref: The parent_ref of this TypedObject.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def config_values(self):
        """
        Gets the config_values of this TypedObject.

        :return: The config_values of this TypedObject.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this TypedObject.

        :param config_values: The config_values of this TypedObject.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    @property
    def object_status(self):
        """
        Gets the object_status of this TypedObject.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this TypedObject.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this TypedObject.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this TypedObject.
        :type: int
        """
        self._object_status = object_status

    @property
    def name(self):
        """
        Gets the name of this TypedObject.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this TypedObject.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TypedObject.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this TypedObject.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TypedObject.
        Detailed description for the object.


        :return: The description of this TypedObject.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TypedObject.
        Detailed description for the object.


        :param description: The description of this TypedObject.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobSummary(object):
    """
    Details of a job. Jobs are scheduled instances of a job definition.
    """

    #: A constant which can be used with the lifecycle_state property of a JobSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a JobSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a JobSummary.
    #: This constant has a value of "EXPIRED"
    LIFECYCLE_STATE_EXPIRED = "EXPIRED"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "HARVEST"
    JOB_TYPE_HARVEST = "HARVEST"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "PROFILING"
    JOB_TYPE_PROFILING = "PROFILING"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "SAMPLING"
    JOB_TYPE_SAMPLING = "SAMPLING"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "PREVIEW"
    JOB_TYPE_PREVIEW = "PREVIEW"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "IMPORT"
    JOB_TYPE_IMPORT = "IMPORT"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "EXPORT"
    JOB_TYPE_EXPORT = "EXPORT"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "IMPORT_GLOSSARY"
    JOB_TYPE_IMPORT_GLOSSARY = "IMPORT_GLOSSARY"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "EXPORT_GLOSSARY"
    JOB_TYPE_EXPORT_GLOSSARY = "EXPORT_GLOSSARY"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "INTERNAL"
    JOB_TYPE_INTERNAL = "INTERNAL"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "PURGE"
    JOB_TYPE_PURGE = "PURGE"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "IMMEDIATE"
    JOB_TYPE_IMMEDIATE = "IMMEDIATE"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "SCHEDULED"
    JOB_TYPE_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "IMMEDIATE_EXECUTION"
    JOB_TYPE_IMMEDIATE_EXECUTION = "IMMEDIATE_EXECUTION"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "SCHEDULED_EXECUTION"
    JOB_TYPE_SCHEDULED_EXECUTION = "SCHEDULED_EXECUTION"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "SCHEDULED_EXECUTION_INSTANCE"
    JOB_TYPE_SCHEDULED_EXECUTION_INSTANCE = "SCHEDULED_EXECUTION_INSTANCE"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "ASYNC_DELETE"
    JOB_TYPE_ASYNC_DELETE = "ASYNC_DELETE"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "IMPORT_DATA_ASSET"
    JOB_TYPE_IMPORT_DATA_ASSET = "IMPORT_DATA_ASSET"

    def __init__(self, **kwargs):
        """
        Initializes a new JobSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this JobSummary.
        :type key: str

        :param uri:
            The value to assign to the uri property of this JobSummary.
        :type uri: str

        :param display_name:
            The value to assign to the display_name property of this JobSummary.
        :type display_name: str

        :param catalog_id:
            The value to assign to the catalog_id property of this JobSummary.
        :type catalog_id: str

        :param job_definition_key:
            The value to assign to the job_definition_key property of this JobSummary.
        :type job_definition_key: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this JobSummary.
            Allowed values for this property are: "ACTIVE", "INACTIVE", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param job_type:
            The value to assign to the job_type property of this JobSummary.
            Allowed values for this property are: "HARVEST", "PROFILING", "SAMPLING", "PREVIEW", "IMPORT", "EXPORT", "IMPORT_GLOSSARY", "EXPORT_GLOSSARY", "INTERNAL", "PURGE", "IMMEDIATE", "SCHEDULED", "IMMEDIATE_EXECUTION", "SCHEDULED_EXECUTION", "SCHEDULED_EXECUTION_INSTANCE", "ASYNC_DELETE", "IMPORT_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type job_type: str

        :param schedule_type:
            The value to assign to the schedule_type property of this JobSummary.
        :type schedule_type: str

        :param description:
            The value to assign to the description property of this JobSummary.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this JobSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this JobSummary.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this JobSummary.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this JobSummary.
        :type updated_by_id: str

        :param schedule_cron_expression:
            The value to assign to the schedule_cron_expression property of this JobSummary.
        :type schedule_cron_expression: str

        :param time_schedule_begin:
            The value to assign to the time_schedule_begin property of this JobSummary.
        :type time_schedule_begin: datetime

        :param execution_count:
            The value to assign to the execution_count property of this JobSummary.
        :type execution_count: int

        :param time_of_latest_execution:
            The value to assign to the time_of_latest_execution property of this JobSummary.
        :type time_of_latest_execution: datetime

        :param job_definition_name:
            The value to assign to the job_definition_name property of this JobSummary.
        :type job_definition_name: str

        :param data_asset_key:
            The value to assign to the data_asset_key property of this JobSummary.
        :type data_asset_key: str

        :param error_code:
            The value to assign to the error_code property of this JobSummary.
        :type error_code: str

        :param error_message:
            The value to assign to the error_message property of this JobSummary.
        :type error_message: str

        :param executions:
            The value to assign to the executions property of this JobSummary.
        :type executions: list[oci.data_catalog.models.JobExecutionSummary]

        """
        self.swagger_types = {
            'key': 'str',
            'uri': 'str',
            'display_name': 'str',
            'catalog_id': 'str',
            'job_definition_key': 'str',
            'lifecycle_state': 'str',
            'job_type': 'str',
            'schedule_type': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'schedule_cron_expression': 'str',
            'time_schedule_begin': 'datetime',
            'execution_count': 'int',
            'time_of_latest_execution': 'datetime',
            'job_definition_name': 'str',
            'data_asset_key': 'str',
            'error_code': 'str',
            'error_message': 'str',
            'executions': 'list[JobExecutionSummary]'
        }

        self.attribute_map = {
            'key': 'key',
            'uri': 'uri',
            'display_name': 'displayName',
            'catalog_id': 'catalogId',
            'job_definition_key': 'jobDefinitionKey',
            'lifecycle_state': 'lifecycleState',
            'job_type': 'jobType',
            'schedule_type': 'scheduleType',
            'description': 'description',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'schedule_cron_expression': 'scheduleCronExpression',
            'time_schedule_begin': 'timeScheduleBegin',
            'execution_count': 'executionCount',
            'time_of_latest_execution': 'timeOfLatestExecution',
            'job_definition_name': 'jobDefinitionName',
            'data_asset_key': 'dataAssetKey',
            'error_code': 'errorCode',
            'error_message': 'errorMessage',
            'executions': 'executions'
        }

        self._key = None
        self._uri = None
        self._display_name = None
        self._catalog_id = None
        self._job_definition_key = None
        self._lifecycle_state = None
        self._job_type = None
        self._schedule_type = None
        self._description = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._schedule_cron_expression = None
        self._time_schedule_begin = None
        self._execution_count = None
        self._time_of_latest_execution = None
        self._job_definition_name = None
        self._data_asset_key = None
        self._error_code = None
        self._error_message = None
        self._executions = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this JobSummary.
        Unique key of the job.


        :return: The key of this JobSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this JobSummary.
        Unique key of the job.


        :param key: The key of this JobSummary.
        :type: str
        """
        self._key = key

    @property
    def uri(self):
        """
        Gets the uri of this JobSummary.
        URI to the job instance in the API.


        :return: The uri of this JobSummary.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this JobSummary.
        URI to the job instance in the API.


        :param uri: The uri of this JobSummary.
        :type: str
        """
        self._uri = uri

    @property
    def display_name(self):
        """
        Gets the display_name of this JobSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this JobSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this JobSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this JobSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def catalog_id(self):
        """
        Gets the catalog_id of this JobSummary.
        The data catalog's OCID.


        :return: The catalog_id of this JobSummary.
        :rtype: str
        """
        return self._catalog_id

    @catalog_id.setter
    def catalog_id(self, catalog_id):
        """
        Sets the catalog_id of this JobSummary.
        The data catalog's OCID.


        :param catalog_id: The catalog_id of this JobSummary.
        :type: str
        """
        self._catalog_id = catalog_id

    @property
    def job_definition_key(self):
        """
        Gets the job_definition_key of this JobSummary.
        The unique key of the job definition resource that defined the scope of this job.


        :return: The job_definition_key of this JobSummary.
        :rtype: str
        """
        return self._job_definition_key

    @job_definition_key.setter
    def job_definition_key(self, job_definition_key):
        """
        Sets the job_definition_key of this JobSummary.
        The unique key of the job definition resource that defined the scope of this job.


        :param job_definition_key: The job_definition_key of this JobSummary.
        :type: str
        """
        self._job_definition_key = job_definition_key

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this JobSummary.
        Lifecycle state of the job, such as running, paused, or completed.

        Allowed values for this property are: "ACTIVE", "INACTIVE", "EXPIRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this JobSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this JobSummary.
        Lifecycle state of the job, such as running, paused, or completed.


        :param lifecycle_state: The lifecycle_state of this JobSummary.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE", "EXPIRED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def job_type(self):
        """
        Gets the job_type of this JobSummary.
        Type of the job.

        Allowed values for this property are: "HARVEST", "PROFILING", "SAMPLING", "PREVIEW", "IMPORT", "EXPORT", "IMPORT_GLOSSARY", "EXPORT_GLOSSARY", "INTERNAL", "PURGE", "IMMEDIATE", "SCHEDULED", "IMMEDIATE_EXECUTION", "SCHEDULED_EXECUTION", "SCHEDULED_EXECUTION_INSTANCE", "ASYNC_DELETE", "IMPORT_DATA_ASSET", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The job_type of this JobSummary.
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """
        Sets the job_type of this JobSummary.
        Type of the job.


        :param job_type: The job_type of this JobSummary.
        :type: str
        """
        allowed_values = ["HARVEST", "PROFILING", "SAMPLING", "PREVIEW", "IMPORT", "EXPORT", "IMPORT_GLOSSARY", "EXPORT_GLOSSARY", "INTERNAL", "PURGE", "IMMEDIATE", "SCHEDULED", "IMMEDIATE_EXECUTION", "SCHEDULED_EXECUTION", "SCHEDULED_EXECUTION_INSTANCE", "ASYNC_DELETE", "IMPORT_DATA_ASSET"]
        if not value_allowed_none_or_none_sentinel(job_type, allowed_values):
            job_type = 'UNKNOWN_ENUM_VALUE'
        self._job_type = job_type

    @property
    def schedule_type(self):
        """
        Gets the schedule_type of this JobSummary.
        Type of job schedule that is inferred from the scheduling properties.


        :return: The schedule_type of this JobSummary.
        :rtype: str
        """
        return self._schedule_type

    @schedule_type.setter
    def schedule_type(self, schedule_type):
        """
        Sets the schedule_type of this JobSummary.
        Type of job schedule that is inferred from the scheduling properties.


        :param schedule_type: The schedule_type of this JobSummary.
        :type: str
        """
        self._schedule_type = schedule_type

    @property
    def description(self):
        """
        Gets the description of this JobSummary.
        Detailed description of the job.


        :return: The description of this JobSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this JobSummary.
        Detailed description of the job.


        :param description: The description of this JobSummary.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this JobSummary.
        The date and time the job was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this JobSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this JobSummary.
        The date and time the job was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this JobSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this JobSummary.
        Time that this job was last updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this JobSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this JobSummary.
        Time that this job was last updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this JobSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this JobSummary.
        OCID of the user who created this job.


        :return: The created_by_id of this JobSummary.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this JobSummary.
        OCID of the user who created this job.


        :param created_by_id: The created_by_id of this JobSummary.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this JobSummary.
        OCID of the user who updated this job.


        :return: The updated_by_id of this JobSummary.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this JobSummary.
        OCID of the user who updated this job.


        :param updated_by_id: The updated_by_id of this JobSummary.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def schedule_cron_expression(self):
        """
        Gets the schedule_cron_expression of this JobSummary.
        Schedule specified in the cron expression format that has seven fields for second, minute, hour, day-of-month, month, day-of-week, year.
        It can also include special characters like * for all and ? for any. There are also pre-defined schedules that can be specified using
        special strings. For example, @hourly will run the job every hour.


        :return: The schedule_cron_expression of this JobSummary.
        :rtype: str
        """
        return self._schedule_cron_expression

    @schedule_cron_expression.setter
    def schedule_cron_expression(self, schedule_cron_expression):
        """
        Sets the schedule_cron_expression of this JobSummary.
        Schedule specified in the cron expression format that has seven fields for second, minute, hour, day-of-month, month, day-of-week, year.
        It can also include special characters like * for all and ? for any. There are also pre-defined schedules that can be specified using
        special strings. For example, @hourly will run the job every hour.


        :param schedule_cron_expression: The schedule_cron_expression of this JobSummary.
        :type: str
        """
        self._schedule_cron_expression = schedule_cron_expression

    @property
    def time_schedule_begin(self):
        """
        Gets the time_schedule_begin of this JobSummary.
        Date that the schedule should be operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_schedule_begin of this JobSummary.
        :rtype: datetime
        """
        return self._time_schedule_begin

    @time_schedule_begin.setter
    def time_schedule_begin(self, time_schedule_begin):
        """
        Sets the time_schedule_begin of this JobSummary.
        Date that the schedule should be operational. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_schedule_begin: The time_schedule_begin of this JobSummary.
        :type: datetime
        """
        self._time_schedule_begin = time_schedule_begin

    @property
    def execution_count(self):
        """
        Gets the execution_count of this JobSummary.
        The total number of executions for this job schedule.


        :return: The execution_count of this JobSummary.
        :rtype: int
        """
        return self._execution_count

    @execution_count.setter
    def execution_count(self, execution_count):
        """
        Sets the execution_count of this JobSummary.
        The total number of executions for this job schedule.


        :param execution_count: The execution_count of this JobSummary.
        :type: int
        """
        self._execution_count = execution_count

    @property
    def time_of_latest_execution(self):
        """
        Gets the time_of_latest_execution of this JobSummary.
        The date and time of the most recent execution for this job, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_latest_execution of this JobSummary.
        :rtype: datetime
        """
        return self._time_of_latest_execution

    @time_of_latest_execution.setter
    def time_of_latest_execution(self, time_of_latest_execution):
        """
        Sets the time_of_latest_execution of this JobSummary.
        The date and time of the most recent execution for this job, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_latest_execution: The time_of_latest_execution of this JobSummary.
        :type: datetime
        """
        self._time_of_latest_execution = time_of_latest_execution

    @property
    def job_definition_name(self):
        """
        Gets the job_definition_name of this JobSummary.
        The display name of the job definition resource that defined the scope of this job.


        :return: The job_definition_name of this JobSummary.
        :rtype: str
        """
        return self._job_definition_name

    @job_definition_name.setter
    def job_definition_name(self, job_definition_name):
        """
        Sets the job_definition_name of this JobSummary.
        The display name of the job definition resource that defined the scope of this job.


        :param job_definition_name: The job_definition_name of this JobSummary.
        :type: str
        """
        self._job_definition_name = job_definition_name

    @property
    def data_asset_key(self):
        """
        Gets the data_asset_key of this JobSummary.
        Unique key of the data asset to which this job applies, if the job involves a data asset.


        :return: The data_asset_key of this JobSummary.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this JobSummary.
        Unique key of the data asset to which this job applies, if the job involves a data asset.


        :param data_asset_key: The data_asset_key of this JobSummary.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def error_code(self):
        """
        Gets the error_code of this JobSummary.
        Error code returned from the latest job execution for this job. Useful when the latest Job execution is in FAILED state.


        :return: The error_code of this JobSummary.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this JobSummary.
        Error code returned from the latest job execution for this job. Useful when the latest Job execution is in FAILED state.


        :param error_code: The error_code of this JobSummary.
        :type: str
        """
        self._error_code = error_code

    @property
    def error_message(self):
        """
        Gets the error_message of this JobSummary.
        Error message returned from the latest job execution for this job. Useful when the latest Job Execution is in a FAILED state.


        :return: The error_message of this JobSummary.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this JobSummary.
        Error message returned from the latest job execution for this job. Useful when the latest Job Execution is in a FAILED state.


        :param error_message: The error_message of this JobSummary.
        :type: str
        """
        self._error_message = error_message

    @property
    def executions(self):
        """
        Gets the executions of this JobSummary.
        Array of the executions summary associated with this job.


        :return: The executions of this JobSummary.
        :rtype: list[oci.data_catalog.models.JobExecutionSummary]
        """
        return self._executions

    @executions.setter
    def executions(self, executions):
        """
        Sets the executions of this JobSummary.
        Array of the executions summary associated with this job.


        :param executions: The executions of this JobSummary.
        :type: list[oci.data_catalog.models.JobExecutionSummary]
        """
        self._executions = executions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Action(object):
    """
    An object that represents an action to trigger for events that match a rule.
    """

    #: A constant which can be used with the action_type property of a Action.
    #: This constant has a value of "ONS"
    ACTION_TYPE_ONS = "ONS"

    #: A constant which can be used with the action_type property of a Action.
    #: This constant has a value of "OSS"
    ACTION_TYPE_OSS = "OSS"

    #: A constant which can be used with the action_type property of a Action.
    #: This constant has a value of "FAAS"
    ACTION_TYPE_FAAS = "FAAS"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Action.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new Action object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.events.models.StreamingServiceAction`
        * :class:`~oci.events.models.NotificationServiceAction`
        * :class:`~oci.events.models.FaaSAction`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_type:
            The value to assign to the action_type property of this Action.
            Allowed values for this property are: "ONS", "OSS", "FAAS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action_type: str

        :param id:
            The value to assign to the id property of this Action.
        :type id: str

        :param lifecycle_message:
            The value to assign to the lifecycle_message property of this Action.
        :type lifecycle_message: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Action.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_enabled:
            The value to assign to the is_enabled property of this Action.
        :type is_enabled: bool

        :param description:
            The value to assign to the description property of this Action.
        :type description: str

        """
        self.swagger_types = {
            'action_type': 'str',
            'id': 'str',
            'lifecycle_message': 'str',
            'lifecycle_state': 'str',
            'is_enabled': 'bool',
            'description': 'str'
        }

        self.attribute_map = {
            'action_type': 'actionType',
            'id': 'id',
            'lifecycle_message': 'lifecycleMessage',
            'lifecycle_state': 'lifecycleState',
            'is_enabled': 'isEnabled',
            'description': 'description'
        }

        self._action_type = None
        self._id = None
        self._lifecycle_message = None
        self._lifecycle_state = None
        self._is_enabled = None
        self._description = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['actionType']

        if type == 'OSS':
            return 'StreamingServiceAction'

        if type == 'ONS':
            return 'NotificationServiceAction'

        if type == 'FAAS':
            return 'FaaSAction'
        else:
            return 'Action'

    @property
    def action_type(self):
        """
        **[Required]** Gets the action_type of this Action.
        The action to perform if the condition in the rule matches an event.

        * **ONS:** Send to an Oracle Notification Service topic.
        * **OSS:** Send to a stream from Oracle Streaming Service.
        * **FAAS:** Send to an Oracle Functions Service endpoint.

        Allowed values for this property are: "ONS", "OSS", "FAAS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action_type of this Action.
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """
        Sets the action_type of this Action.
        The action to perform if the condition in the rule matches an event.

        * **ONS:** Send to an Oracle Notification Service topic.
        * **OSS:** Send to a stream from Oracle Streaming Service.
        * **FAAS:** Send to an Oracle Functions Service endpoint.


        :param action_type: The action_type of this Action.
        :type: str
        """
        allowed_values = ["ONS", "OSS", "FAAS"]
        if not value_allowed_none_or_none_sentinel(action_type, allowed_values):
            action_type = 'UNKNOWN_ENUM_VALUE'
        self._action_type = action_type

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Action.
        The `OCID`__ of the action.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Action.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Action.
        The `OCID`__ of the action.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Action.
        :type: str
        """
        self._id = id

    @property
    def lifecycle_message(self):
        """
        **[Required]** Gets the lifecycle_message of this Action.
        A message generated by the Events service about the current state of this action.


        :return: The lifecycle_message of this Action.
        :rtype: str
        """
        return self._lifecycle_message

    @lifecycle_message.setter
    def lifecycle_message(self, lifecycle_message):
        """
        Sets the lifecycle_message of this Action.
        A message generated by the Events service about the current state of this action.


        :param lifecycle_message: The lifecycle_message of this Action.
        :type: str
        """
        self._lifecycle_message = lifecycle_message

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Action.
        The current state of the rule.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Action.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Action.
        The current state of the rule.


        :param lifecycle_state: The lifecycle_state of this Action.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this Action.
        Whether or not this action is currently enabled.

        Example: `true`


        :return: The is_enabled of this Action.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this Action.
        Whether or not this action is currently enabled.

        Example: `true`


        :param is_enabled: The is_enabled of this Action.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def description(self):
        """
        Gets the description of this Action.
        A string that describes the details of the action. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :return: The description of this Action.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Action.
        A string that describes the details of the action. It does not have to be unique, and you can change it. Avoid entering
        confidential information.


        :param description: The description of this Action.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_channel_target_details import CreateChannelTargetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateChannelTargetFromDbSystemDetails(CreateChannelTargetDetails):
    """
    Parameters detailing how to provision the target endpoint that is a DB System.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateChannelTargetFromDbSystemDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.mysql.models.CreateChannelTargetFromDbSystemDetails.target_type` attribute
        of this class is ``DBSYSTEM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target_type:
            The value to assign to the target_type property of this CreateChannelTargetFromDbSystemDetails.
        :type target_type: str

        :param db_system_id:
            The value to assign to the db_system_id property of this CreateChannelTargetFromDbSystemDetails.
        :type db_system_id: str

        :param channel_name:
            The value to assign to the channel_name property of this CreateChannelTargetFromDbSystemDetails.
        :type channel_name: str

        :param applier_username:
            The value to assign to the applier_username property of this CreateChannelTargetFromDbSystemDetails.
        :type applier_username: str

        """
        self.swagger_types = {
            'target_type': 'str',
            'db_system_id': 'str',
            'channel_name': 'str',
            'applier_username': 'str'
        }

        self.attribute_map = {
            'target_type': 'targetType',
            'db_system_id': 'dbSystemId',
            'channel_name': 'channelName',
            'applier_username': 'applierUsername'
        }

        self._target_type = None
        self._db_system_id = None
        self._channel_name = None
        self._applier_username = None
        self._target_type = 'DBSYSTEM'

    @property
    def db_system_id(self):
        """
        **[Required]** Gets the db_system_id of this CreateChannelTargetFromDbSystemDetails.
        The OCID of the target DB System.


        :return: The db_system_id of this CreateChannelTargetFromDbSystemDetails.
        :rtype: str
        """
        return self._db_system_id

    @db_system_id.setter
    def db_system_id(self, db_system_id):
        """
        Sets the db_system_id of this CreateChannelTargetFromDbSystemDetails.
        The OCID of the target DB System.


        :param db_system_id: The db_system_id of this CreateChannelTargetFromDbSystemDetails.
        :type: str
        """
        self._db_system_id = db_system_id

    @property
    def channel_name(self):
        """
        Gets the channel_name of this CreateChannelTargetFromDbSystemDetails.
        The case-insensitive name that identifies the replication channel. Channel names
        must follow the rules defined for `MySQL identifiers`__.
        The names of non-Deleted Channels must be unique for each DB System.

        __ https://dev.mysql.com/doc/refman/8.0/en/identifiers.html


        :return: The channel_name of this CreateChannelTargetFromDbSystemDetails.
        :rtype: str
        """
        return self._channel_name

    @channel_name.setter
    def channel_name(self, channel_name):
        """
        Sets the channel_name of this CreateChannelTargetFromDbSystemDetails.
        The case-insensitive name that identifies the replication channel. Channel names
        must follow the rules defined for `MySQL identifiers`__.
        The names of non-Deleted Channels must be unique for each DB System.

        __ https://dev.mysql.com/doc/refman/8.0/en/identifiers.html


        :param channel_name: The channel_name of this CreateChannelTargetFromDbSystemDetails.
        :type: str
        """
        self._channel_name = channel_name

    @property
    def applier_username(self):
        """
        Gets the applier_username of this CreateChannelTargetFromDbSystemDetails.
        The username for the replication applier of the target MySQL DB System.


        :return: The applier_username of this CreateChannelTargetFromDbSystemDetails.
        :rtype: str
        """
        return self._applier_username

    @applier_username.setter
    def applier_username(self, applier_username):
        """
        Sets the applier_username of this CreateChannelTargetFromDbSystemDetails.
        The username for the replication applier of the target MySQL DB System.


        :param applier_username: The applier_username of this CreateChannelTargetFromDbSystemDetails.
        :type: str
        """
        self._applier_username = applier_username

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ShapeSummary(object):
    """
    The shape of the DB System. The shape determines resources to allocate
    to the DB System - CPU cores and memory for VM shapes; CPU cores, memory
    and storage for non-VM (or bare metal) shapes.  For a description of
    shapes, see `DB System Shape Options`__.

    __ https://docs.cloud.oracle.com/mysql-database/doc/shapes.htm
    """

    #: A constant which can be used with the is_supported_for property of a ShapeSummary.
    #: This constant has a value of "DBSYSTEM"
    IS_SUPPORTED_FOR_DBSYSTEM = "DBSYSTEM"

    #: A constant which can be used with the is_supported_for property of a ShapeSummary.
    #: This constant has a value of "ANALYTICSCLUSTER"
    IS_SUPPORTED_FOR_ANALYTICSCLUSTER = "ANALYTICSCLUSTER"

    #: A constant which can be used with the is_supported_for property of a ShapeSummary.
    #: This constant has a value of "HEATWAVECLUSTER"
    IS_SUPPORTED_FOR_HEATWAVECLUSTER = "HEATWAVECLUSTER"

    def __init__(self, **kwargs):
        """
        Initializes a new ShapeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ShapeSummary.
        :type name: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this ShapeSummary.
        :type cpu_core_count: int

        :param memory_size_in_gbs:
            The value to assign to the memory_size_in_gbs property of this ShapeSummary.
        :type memory_size_in_gbs: int

        :param is_supported_for:
            The value to assign to the is_supported_for property of this ShapeSummary.
            Allowed values for items in this list are: "DBSYSTEM", "ANALYTICSCLUSTER", "HEATWAVECLUSTER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type is_supported_for: list[str]

        """
        self.swagger_types = {
            'name': 'str',
            'cpu_core_count': 'int',
            'memory_size_in_gbs': 'int',
            'is_supported_for': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'cpu_core_count': 'cpuCoreCount',
            'memory_size_in_gbs': 'memorySizeInGBs',
            'is_supported_for': 'isSupportedFor'
        }

        self._name = None
        self._cpu_core_count = None
        self._memory_size_in_gbs = None
        self._is_supported_for = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ShapeSummary.
        The name of the shape used for the DB System.


        :return: The name of this ShapeSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ShapeSummary.
        The name of the shape used for the DB System.


        :param name: The name of this ShapeSummary.
        :type: str
        """
        self._name = name

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this ShapeSummary.
        The number of CPU Cores the Instance provides. These are \"OCPU\"s.


        :return: The cpu_core_count of this ShapeSummary.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this ShapeSummary.
        The number of CPU Cores the Instance provides. These are \"OCPU\"s.


        :param cpu_core_count: The cpu_core_count of this ShapeSummary.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def memory_size_in_gbs(self):
        """
        **[Required]** Gets the memory_size_in_gbs of this ShapeSummary.
        The amount of RAM the Instance provides. This is an IEC base-2 number.


        :return: The memory_size_in_gbs of this ShapeSummary.
        :rtype: int
        """
        return self._memory_size_in_gbs

    @memory_size_in_gbs.setter
    def memory_size_in_gbs(self, memory_size_in_gbs):
        """
        Sets the memory_size_in_gbs of this ShapeSummary.
        The amount of RAM the Instance provides. This is an IEC base-2 number.


        :param memory_size_in_gbs: The memory_size_in_gbs of this ShapeSummary.
        :type: int
        """
        self._memory_size_in_gbs = memory_size_in_gbs

    @property
    def is_supported_for(self):
        """
        Gets the is_supported_for of this ShapeSummary.
        What service features the shape is supported for.

        Allowed values for items in this list are: "DBSYSTEM", "ANALYTICSCLUSTER", "HEATWAVECLUSTER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The is_supported_for of this ShapeSummary.
        :rtype: list[str]
        """
        return self._is_supported_for

    @is_supported_for.setter
    def is_supported_for(self, is_supported_for):
        """
        Sets the is_supported_for of this ShapeSummary.
        What service features the shape is supported for.


        :param is_supported_for: The is_supported_for of this ShapeSummary.
        :type: list[str]
        """
        allowed_values = ["DBSYSTEM", "ANALYTICSCLUSTER", "HEATWAVECLUSTER"]
        if is_supported_for:
            is_supported_for[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in is_supported_for]
        self._is_supported_for = is_supported_for

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Node(object):
    """
    Details about a node.
    """

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Node.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "MASTER"
    NODE_TYPE_MASTER = "MASTER"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "EDGE"
    NODE_TYPE_EDGE = "EDGE"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "UTILITY"
    NODE_TYPE_UTILITY = "UTILITY"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "WORKER"
    NODE_TYPE_WORKER = "WORKER"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "BURSTING"
    NODE_TYPE_BURSTING = "BURSTING"

    #: A constant which can be used with the node_type property of a Node.
    #: This constant has a value of "CLOUD_SQL"
    NODE_TYPE_CLOUD_SQL = "CLOUD_SQL"

    def __init__(self, **kwargs):
        """
        Initializes a new Node object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param instance_id:
            The value to assign to the instance_id property of this Node.
        :type instance_id: str

        :param display_name:
            The value to assign to the display_name property of this Node.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Node.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param node_type:
            The value to assign to the node_type property of this Node.
            Allowed values for this property are: "MASTER", "EDGE", "UTILITY", "WORKER", "BURSTING", "CLOUD_SQL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type node_type: str

        :param shape:
            The value to assign to the shape property of this Node.
        :type shape: str

        :param attached_block_volumes:
            The value to assign to the attached_block_volumes property of this Node.
        :type attached_block_volumes: list[oci.bds.models.VolumeAttachmentDetail]

        :param subnet_id:
            The value to assign to the subnet_id property of this Node.
        :type subnet_id: str

        :param ip_address:
            The value to assign to the ip_address property of this Node.
        :type ip_address: str

        :param hostname:
            The value to assign to the hostname property of this Node.
        :type hostname: str

        :param image_id:
            The value to assign to the image_id property of this Node.
        :type image_id: str

        :param ssh_fingerprint:
            The value to assign to the ssh_fingerprint property of this Node.
        :type ssh_fingerprint: str

        :param availability_domain:
            The value to assign to the availability_domain property of this Node.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this Node.
        :type fault_domain: str

        :param time_created:
            The value to assign to the time_created property of this Node.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Node.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'instance_id': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'node_type': 'str',
            'shape': 'str',
            'attached_block_volumes': 'list[VolumeAttachmentDetail]',
            'subnet_id': 'str',
            'ip_address': 'str',
            'hostname': 'str',
            'image_id': 'str',
            'ssh_fingerprint': 'str',
            'availability_domain': 'str',
            'fault_domain': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'instance_id': 'instanceId',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'node_type': 'nodeType',
            'shape': 'shape',
            'attached_block_volumes': 'attachedBlockVolumes',
            'subnet_id': 'subnetId',
            'ip_address': 'ipAddress',
            'hostname': 'hostname',
            'image_id': 'imageId',
            'ssh_fingerprint': 'sshFingerprint',
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._instance_id = None
        self._display_name = None
        self._lifecycle_state = None
        self._node_type = None
        self._shape = None
        self._attached_block_volumes = None
        self._subnet_id = None
        self._ip_address = None
        self._hostname = None
        self._image_id = None
        self._ssh_fingerprint = None
        self._availability_domain = None
        self._fault_domain = None
        self._time_created = None
        self._time_updated = None

    @property
    def instance_id(self):
        """
        **[Required]** Gets the instance_id of this Node.
        The OCID of the underlying Oracle Cloud Infrastructure Compute instance.


        :return: The instance_id of this Node.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this Node.
        The OCID of the underlying Oracle Cloud Infrastructure Compute instance.


        :param instance_id: The instance_id of this Node.
        :type: str
        """
        self._instance_id = instance_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Node.
        The name of the node.


        :return: The display_name of this Node.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Node.
        The name of the node.


        :param display_name: The display_name of this Node.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Node.
        The state of the node.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Node.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Node.
        The state of the node.


        :param lifecycle_state: The lifecycle_state of this Node.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def node_type(self):
        """
        **[Required]** Gets the node_type of this Node.
        Cluster node type.

        Allowed values for this property are: "MASTER", "EDGE", "UTILITY", "WORKER", "BURSTING", "CLOUD_SQL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The node_type of this Node.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this Node.
        Cluster node type.


        :param node_type: The node_type of this Node.
        :type: str
        """
        allowed_values = ["MASTER", "EDGE", "UTILITY", "WORKER", "BURSTING", "CLOUD_SQL"]
        if not value_allowed_none_or_none_sentinel(node_type, allowed_values):
            node_type = 'UNKNOWN_ENUM_VALUE'
        self._node_type = node_type

    @property
    def shape(self):
        """
        **[Required]** Gets the shape of this Node.
        Shape of the node.


        :return: The shape of this Node.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this Node.
        Shape of the node.


        :param shape: The shape of this Node.
        :type: str
        """
        self._shape = shape

    @property
    def attached_block_volumes(self):
        """
        Gets the attached_block_volumes of this Node.
        The list of block volumes attached to a given node.


        :return: The attached_block_volumes of this Node.
        :rtype: list[oci.bds.models.VolumeAttachmentDetail]
        """
        return self._attached_block_volumes

    @attached_block_volumes.setter
    def attached_block_volumes(self, attached_block_volumes):
        """
        Sets the attached_block_volumes of this Node.
        The list of block volumes attached to a given node.


        :param attached_block_volumes: The attached_block_volumes of this Node.
        :type: list[oci.bds.models.VolumeAttachmentDetail]
        """
        self._attached_block_volumes = attached_block_volumes

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this Node.
        The OCID of the subnet in which the node is to be created.


        :return: The subnet_id of this Node.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this Node.
        The OCID of the subnet in which the node is to be created.


        :param subnet_id: The subnet_id of this Node.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def ip_address(self):
        """
        **[Required]** Gets the ip_address of this Node.
        IP address of the node.


        :return: The ip_address of this Node.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this Node.
        IP address of the node.


        :param ip_address: The ip_address of this Node.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def hostname(self):
        """
        Gets the hostname of this Node.
        The fully-qualified hostname (FQDN) of the node.


        :return: The hostname of this Node.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this Node.
        The fully-qualified hostname (FQDN) of the node.


        :param hostname: The hostname of this Node.
        :type: str
        """
        self._hostname = hostname

    @property
    def image_id(self):
        """
        Gets the image_id of this Node.
        The OCID of the image from which the node was created.


        :return: The image_id of this Node.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this Node.
        The OCID of the image from which the node was created.


        :param image_id: The image_id of this Node.
        :type: str
        """
        self._image_id = image_id

    @property
    def ssh_fingerprint(self):
        """
        **[Required]** Gets the ssh_fingerprint of this Node.
        The fingerprint of the SSH key used for node access.


        :return: The ssh_fingerprint of this Node.
        :rtype: str
        """
        return self._ssh_fingerprint

    @ssh_fingerprint.setter
    def ssh_fingerprint(self, ssh_fingerprint):
        """
        Sets the ssh_fingerprint of this Node.
        The fingerprint of the SSH key used for node access.


        :param ssh_fingerprint: The ssh_fingerprint of this Node.
        :type: str
        """
        self._ssh_fingerprint = ssh_fingerprint

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this Node.
        The name of the availability domain in which the node is running.


        :return: The availability_domain of this Node.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this Node.
        The name of the availability domain in which the node is running.


        :param availability_domain: The availability_domain of this Node.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        **[Required]** Gets the fault_domain of this Node.
        The name of the fault domain in which the node is running.


        :return: The fault_domain of this Node.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this Node.
        The name of the fault domain in which the node is running.


        :param fault_domain: The fault_domain of this Node.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Node.
        The time the node was created, shown as an RFC 3339 formatted datetime string.


        :return: The time_created of this Node.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Node.
        The time the node was created, shown as an RFC 3339 formatted datetime string.


        :param time_created: The time_created of this Node.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Node.
        The time the cluster was updated, shown as an RFC 3339 formatted datetime string.


        :return: The time_updated of this Node.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Node.
        The time the cluster was updated, shown as an RFC 3339 formatted datetime string.


        :param time_updated: The time_updated of this Node.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_column import AbstractColumn
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClassifyColumn(AbstractColumn):
    """
    Column containing query results produced by the query language classify command.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClassifyColumn object with values from keyword arguments. The default value of the :py:attr:`~oci.log_analytics.models.ClassifyColumn.type` attribute
        of this class is ``CLASSIFY_COLUMN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this ClassifyColumn.
            Allowed values for this property are: "COLUMN", "CHART_COLUMN", "CHART_DATA_COLUMN", "TIME_COLUMN", "TREND_COLUMN", "CLASSIFY_COLUMN"
        :type type: str

        :param display_name:
            The value to assign to the display_name property of this ClassifyColumn.
        :type display_name: str

        :param sub_system:
            The value to assign to the sub_system property of this ClassifyColumn.
            Allowed values for this property are: "LOG"
        :type sub_system: str

        :param values:
            The value to assign to the values property of this ClassifyColumn.
        :type values: list[oci.log_analytics.models.FieldValue]

        :param is_list_of_values:
            The value to assign to the is_list_of_values property of this ClassifyColumn.
        :type is_list_of_values: bool

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this ClassifyColumn.
        :type is_multi_valued: bool

        :param is_groupable:
            The value to assign to the is_groupable property of this ClassifyColumn.
        :type is_groupable: bool

        :param is_evaluable:
            The value to assign to the is_evaluable property of this ClassifyColumn.
        :type is_evaluable: bool

        :param value_type:
            The value to assign to the value_type property of this ClassifyColumn.
            Allowed values for this property are: "BOOLEAN", "STRING", "DOUBLE", "FLOAT", "LONG", "INTEGER", "TIMESTAMP", "FACET"
        :type value_type: str

        :param original_display_name:
            The value to assign to the original_display_name property of this ClassifyColumn.
        :type original_display_name: str

        :param internal_name:
            The value to assign to the internal_name property of this ClassifyColumn.
        :type internal_name: str

        :param classify_field_names:
            The value to assign to the classify_field_names property of this ClassifyColumn.
        :type classify_field_names: list[str]

        :param classify_field_null_count:
            The value to assign to the classify_field_null_count property of this ClassifyColumn.
        :type classify_field_null_count: list[int]

        :param classify_anomaly_interval_counts:
            The value to assign to the classify_anomaly_interval_counts property of this ClassifyColumn.
        :type classify_anomaly_interval_counts: list[int]

        :param classify_columns:
            The value to assign to the classify_columns property of this ClassifyColumn.
        :type classify_columns: list[oci.log_analytics.models.AbstractColumn]

        :param classify_result:
            The value to assign to the classify_result property of this ClassifyColumn.
        :type classify_result: list[dict(str, object)]

        :param classify_correlate_columns:
            The value to assign to the classify_correlate_columns property of this ClassifyColumn.
        :type classify_correlate_columns: list[oci.log_analytics.models.AbstractColumn]

        :param classify_correlate_result:
            The value to assign to the classify_correlate_result property of this ClassifyColumn.
        :type classify_correlate_result: list[dict(str, object)]

        """
        self.swagger_types = {
            'type': 'str',
            'display_name': 'str',
            'sub_system': 'str',
            'values': 'list[FieldValue]',
            'is_list_of_values': 'bool',
            'is_multi_valued': 'bool',
            'is_groupable': 'bool',
            'is_evaluable': 'bool',
            'value_type': 'str',
            'original_display_name': 'str',
            'internal_name': 'str',
            'classify_field_names': 'list[str]',
            'classify_field_null_count': 'list[int]',
            'classify_anomaly_interval_counts': 'list[int]',
            'classify_columns': 'list[AbstractColumn]',
            'classify_result': 'list[dict(str, object)]',
            'classify_correlate_columns': 'list[AbstractColumn]',
            'classify_correlate_result': 'list[dict(str, object)]'
        }

        self.attribute_map = {
            'type': 'type',
            'display_name': 'displayName',
            'sub_system': 'subSystem',
            'values': 'values',
            'is_list_of_values': 'isListOfValues',
            'is_multi_valued': 'isMultiValued',
            'is_groupable': 'isGroupable',
            'is_evaluable': 'isEvaluable',
            'value_type': 'valueType',
            'original_display_name': 'originalDisplayName',
            'internal_name': 'internalName',
            'classify_field_names': 'classifyFieldNames',
            'classify_field_null_count': 'classifyFieldNullCount',
            'classify_anomaly_interval_counts': 'classifyAnomalyIntervalCounts',
            'classify_columns': 'classifyColumns',
            'classify_result': 'classifyResult',
            'classify_correlate_columns': 'classifyCorrelateColumns',
            'classify_correlate_result': 'classifyCorrelateResult'
        }

        self._type = None
        self._display_name = None
        self._sub_system = None
        self._values = None
        self._is_list_of_values = None
        self._is_multi_valued = None
        self._is_groupable = None
        self._is_evaluable = None
        self._value_type = None
        self._original_display_name = None
        self._internal_name = None
        self._classify_field_names = None
        self._classify_field_null_count = None
        self._classify_anomaly_interval_counts = None
        self._classify_columns = None
        self._classify_result = None
        self._classify_correlate_columns = None
        self._classify_correlate_result = None
        self._type = 'CLASSIFY_COLUMN'

    @property
    def classify_field_names(self):
        """
        Gets the classify_field_names of this ClassifyColumn.
        A list of fields specified in the classify command in the query string.


        :return: The classify_field_names of this ClassifyColumn.
        :rtype: list[str]
        """
        return self._classify_field_names

    @classify_field_names.setter
    def classify_field_names(self, classify_field_names):
        """
        Sets the classify_field_names of this ClassifyColumn.
        A list of fields specified in the classify command in the query string.


        :param classify_field_names: The classify_field_names of this ClassifyColumn.
        :type: list[str]
        """
        self._classify_field_names = classify_field_names

    @property
    def classify_field_null_count(self):
        """
        Gets the classify_field_null_count of this ClassifyColumn.
        Count of nulls found in each of the fields specified in the classify command in the query string.


        :return: The classify_field_null_count of this ClassifyColumn.
        :rtype: list[int]
        """
        return self._classify_field_null_count

    @classify_field_null_count.setter
    def classify_field_null_count(self, classify_field_null_count):
        """
        Sets the classify_field_null_count of this ClassifyColumn.
        Count of nulls found in each of the fields specified in the classify command in the query string.


        :param classify_field_null_count: The classify_field_null_count of this ClassifyColumn.
        :type: list[int]
        """
        self._classify_field_null_count = classify_field_null_count

    @property
    def classify_anomaly_interval_counts(self):
        """
        Gets the classify_anomaly_interval_counts of this ClassifyColumn.
        Count of anomalies for each timeseries datapoint.


        :return: The classify_anomaly_interval_counts of this ClassifyColumn.
        :rtype: list[int]
        """
        return self._classify_anomaly_interval_counts

    @classify_anomaly_interval_counts.setter
    def classify_anomaly_interval_counts(self, classify_anomaly_interval_counts):
        """
        Sets the classify_anomaly_interval_counts of this ClassifyColumn.
        Count of anomalies for each timeseries datapoint.


        :param classify_anomaly_interval_counts: The classify_anomaly_interval_counts of this ClassifyColumn.
        :type: list[int]
        """
        self._classify_anomaly_interval_counts = classify_anomaly_interval_counts

    @property
    def classify_columns(self):
        """
        Gets the classify_columns of this ClassifyColumn.
        Column descriptors for the classify result.


        :return: The classify_columns of this ClassifyColumn.
        :rtype: list[oci.log_analytics.models.AbstractColumn]
        """
        return self._classify_columns

    @classify_columns.setter
    def classify_columns(self, classify_columns):
        """
        Sets the classify_columns of this ClassifyColumn.
        Column descriptors for the classify result.


        :param classify_columns: The classify_columns of this ClassifyColumn.
        :type: list[oci.log_analytics.models.AbstractColumn]
        """
        self._classify_columns = classify_columns

    @property
    def classify_result(self):
        """
        Gets the classify_result of this ClassifyColumn.
        Results of the classify command.


        :return: The classify_result of this ClassifyColumn.
        :rtype: list[dict(str, object)]
        """
        return self._classify_result

    @classify_result.setter
    def classify_result(self, classify_result):
        """
        Sets the classify_result of this ClassifyColumn.
        Results of the classify command.


        :param classify_result: The classify_result of this ClassifyColumn.
        :type: list[dict(str, object)]
        """
        self._classify_result = classify_result

    @property
    def classify_correlate_columns(self):
        """
        Gets the classify_correlate_columns of this ClassifyColumn.
        Column descriptors of fields with strong correlation with the classify fields.


        :return: The classify_correlate_columns of this ClassifyColumn.
        :rtype: list[oci.log_analytics.models.AbstractColumn]
        """
        return self._classify_correlate_columns

    @classify_correlate_columns.setter
    def classify_correlate_columns(self, classify_correlate_columns):
        """
        Sets the classify_correlate_columns of this ClassifyColumn.
        Column descriptors of fields with strong correlation with the classify fields.


        :param classify_correlate_columns: The classify_correlate_columns of this ClassifyColumn.
        :type: list[oci.log_analytics.models.AbstractColumn]
        """
        self._classify_correlate_columns = classify_correlate_columns

    @property
    def classify_correlate_result(self):
        """
        Gets the classify_correlate_result of this ClassifyColumn.
        Correlation results of the classify command.


        :return: The classify_correlate_result of this ClassifyColumn.
        :rtype: list[dict(str, object)]
        """
        return self._classify_correlate_result

    @classify_correlate_result.setter
    def classify_correlate_result(self, classify_correlate_result):
        """
        Sets the classify_correlate_result of this ClassifyColumn.
        Correlation results of the classify command.


        :param classify_correlate_result: The classify_correlate_result of this ClassifyColumn.
        :type: list[dict(str, object)]
        """
        self._classify_correlate_result = classify_correlate_result

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackupVaultDetails(object):
    """
    BackupVaultDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BackupVaultDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param backup_location:
            The value to assign to the backup_location property of this BackupVaultDetails.
        :type backup_location: oci.key_management.models.BackupLocation

        :param is_include_keys:
            The value to assign to the is_include_keys property of this BackupVaultDetails.
        :type is_include_keys: bool

        """
        self.swagger_types = {
            'backup_location': 'BackupLocation',
            'is_include_keys': 'bool'
        }

        self.attribute_map = {
            'backup_location': 'backupLocation',
            'is_include_keys': 'isIncludeKeys'
        }

        self._backup_location = None
        self._is_include_keys = None

    @property
    def backup_location(self):
        """
        Gets the backup_location of this BackupVaultDetails.

        :return: The backup_location of this BackupVaultDetails.
        :rtype: oci.key_management.models.BackupLocation
        """
        return self._backup_location

    @backup_location.setter
    def backup_location(self, backup_location):
        """
        Sets the backup_location of this BackupVaultDetails.

        :param backup_location: The backup_location of this BackupVaultDetails.
        :type: oci.key_management.models.BackupLocation
        """
        self._backup_location = backup_location

    @property
    def is_include_keys(self):
        """
        Gets the is_include_keys of this BackupVaultDetails.

        :return: The is_include_keys of this BackupVaultDetails.
        :rtype: bool
        """
        return self._is_include_keys

    @is_include_keys.setter
    def is_include_keys(self, is_include_keys):
        """
        Sets the is_include_keys of this BackupVaultDetails.

        :param is_include_keys: The is_include_keys of this BackupVaultDetails.
        :type: bool
        """
        self._is_include_keys = is_include_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateExternalDatabaseConnectorDetails(object):
    """
    Details for creating an external database connector resource.
    """

    #: A constant which can be used with the connector_type property of a CreateExternalDatabaseConnectorDetails.
    #: This constant has a value of "MACS"
    CONNECTOR_TYPE_MACS = "MACS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateExternalDatabaseConnectorDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.database.models.CreateExternalMacsConnectorDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateExternalDatabaseConnectorDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateExternalDatabaseConnectorDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateExternalDatabaseConnectorDetails.
        :type display_name: str

        :param connector_type:
            The value to assign to the connector_type property of this CreateExternalDatabaseConnectorDetails.
            Allowed values for this property are: "MACS"
        :type connector_type: str

        :param external_database_id:
            The value to assign to the external_database_id property of this CreateExternalDatabaseConnectorDetails.
        :type external_database_id: str

        """
        self.swagger_types = {
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'connector_type': 'str',
            'external_database_id': 'str'
        }

        self.attribute_map = {
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'connector_type': 'connectorType',
            'external_database_id': 'externalDatabaseId'
        }

        self._freeform_tags = None
        self._defined_tags = None
        self._display_name = None
        self._connector_type = None
        self._external_database_id = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['connectorType']

        if type == 'MACS':
            return 'CreateExternalMacsConnectorDetails'
        else:
            return 'CreateExternalDatabaseConnectorDetails'

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateExternalDatabaseConnectorDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateExternalDatabaseConnectorDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateExternalDatabaseConnectorDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateExternalDatabaseConnectorDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateExternalDatabaseConnectorDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateExternalDatabaseConnectorDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateExternalDatabaseConnectorDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateExternalDatabaseConnectorDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateExternalDatabaseConnectorDetails.
        The user-friendly name for the
        :func:`create_external_database_connector_details`.
        The name does not have to be unique.


        :return: The display_name of this CreateExternalDatabaseConnectorDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateExternalDatabaseConnectorDetails.
        The user-friendly name for the
        :func:`create_external_database_connector_details`.
        The name does not have to be unique.


        :param display_name: The display_name of this CreateExternalDatabaseConnectorDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def connector_type(self):
        """
        Gets the connector_type of this CreateExternalDatabaseConnectorDetails.
        The type of connector used by the external database resource.

        Allowed values for this property are: "MACS"


        :return: The connector_type of this CreateExternalDatabaseConnectorDetails.
        :rtype: str
        """
        return self._connector_type

    @connector_type.setter
    def connector_type(self, connector_type):
        """
        Sets the connector_type of this CreateExternalDatabaseConnectorDetails.
        The type of connector used by the external database resource.


        :param connector_type: The connector_type of this CreateExternalDatabaseConnectorDetails.
        :type: str
        """
        allowed_values = ["MACS"]
        if not value_allowed_none_or_none_sentinel(connector_type, allowed_values):
            raise ValueError(
                "Invalid value for `connector_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._connector_type = connector_type

    @property
    def external_database_id(self):
        """
        **[Required]** Gets the external_database_id of this CreateExternalDatabaseConnectorDetails.
        The `OCID`__ of the external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The external_database_id of this CreateExternalDatabaseConnectorDetails.
        :rtype: str
        """
        return self._external_database_id

    @external_database_id.setter
    def external_database_id(self, external_database_id):
        """
        Sets the external_database_id of this CreateExternalDatabaseConnectorDetails.
        The `OCID`__ of the external database resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param external_database_id: The external_database_id of this CreateExternalDatabaseConnectorDetails.
        :type: str
        """
        self._external_database_id = external_database_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NatGateway(object):
    """
    A NAT (Network Address Translation) gateway, which represents a router that lets instances
    without public IPs contact the public internet without exposing the instance to inbound
    internet traffic. For more information, see
    `NAT Gateway`__.

    To use any of the API operations, you must be authorized in an
    IAM policy. If you are not authorized, talk to an
    administrator. If you are an administrator who needs to write
    policies to give users access, see `Getting Started with
    Policies`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/NATgateway.htm
    __ https://docs.cloud.oracle.com/iaas/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a NatGateway.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a NatGateway.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a NatGateway.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a NatGateway.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    def __init__(self, **kwargs):
        """
        Initializes a new NatGateway object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this NatGateway.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this NatGateway.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this NatGateway.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this NatGateway.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this NatGateway.
        :type id: str

        :param block_traffic:
            The value to assign to the block_traffic property of this NatGateway.
        :type block_traffic: bool

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this NatGateway.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param nat_ip:
            The value to assign to the nat_ip property of this NatGateway.
        :type nat_ip: str

        :param time_created:
            The value to assign to the time_created property of this NatGateway.
        :type time_created: datetime

        :param vcn_id:
            The value to assign to the vcn_id property of this NatGateway.
        :type vcn_id: str

        :param public_ip_id:
            The value to assign to the public_ip_id property of this NatGateway.
        :type public_ip_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'block_traffic': 'bool',
            'lifecycle_state': 'str',
            'nat_ip': 'str',
            'time_created': 'datetime',
            'vcn_id': 'str',
            'public_ip_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'block_traffic': 'blockTraffic',
            'lifecycle_state': 'lifecycleState',
            'nat_ip': 'natIp',
            'time_created': 'timeCreated',
            'vcn_id': 'vcnId',
            'public_ip_id': 'publicIpId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._id = None
        self._block_traffic = None
        self._lifecycle_state = None
        self._nat_ip = None
        self._time_created = None
        self._vcn_id = None
        self._public_ip_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this NatGateway.
        The `OCID`__ of the compartment that contains
        the NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this NatGateway.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this NatGateway.
        The `OCID`__ of the compartment that contains
        the NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this NatGateway.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this NatGateway.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this NatGateway.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this NatGateway.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this NatGateway.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this NatGateway.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this NatGateway.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this NatGateway.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this NatGateway.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this NatGateway.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this NatGateway.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this NatGateway.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this NatGateway.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this NatGateway.
        The `OCID`__ of the
        NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this NatGateway.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NatGateway.
        The `OCID`__ of the
        NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this NatGateway.
        :type: str
        """
        self._id = id

    @property
    def block_traffic(self):
        """
        **[Required]** Gets the block_traffic of this NatGateway.
        Whether the NAT gateway blocks traffic through it. The default is `false`.

        Example: `true`


        :return: The block_traffic of this NatGateway.
        :rtype: bool
        """
        return self._block_traffic

    @block_traffic.setter
    def block_traffic(self, block_traffic):
        """
        Sets the block_traffic of this NatGateway.
        Whether the NAT gateway blocks traffic through it. The default is `false`.

        Example: `true`


        :param block_traffic: The block_traffic of this NatGateway.
        :type: bool
        """
        self._block_traffic = block_traffic

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this NatGateway.
        The NAT gateway's current state.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this NatGateway.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this NatGateway.
        The NAT gateway's current state.


        :param lifecycle_state: The lifecycle_state of this NatGateway.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "TERMINATING", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def nat_ip(self):
        """
        **[Required]** Gets the nat_ip of this NatGateway.
        The IP address associated with the NAT gateway.


        :return: The nat_ip of this NatGateway.
        :rtype: str
        """
        return self._nat_ip

    @nat_ip.setter
    def nat_ip(self, nat_ip):
        """
        Sets the nat_ip of this NatGateway.
        The IP address associated with the NAT gateway.


        :param nat_ip: The nat_ip of this NatGateway.
        :type: str
        """
        self._nat_ip = nat_ip

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this NatGateway.
        The date and time the NAT gateway was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this NatGateway.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this NatGateway.
        The date and time the NAT gateway was created, in the format defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this NatGateway.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this NatGateway.
        The `OCID`__ of the VCN the NAT gateway
        belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this NatGateway.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this NatGateway.
        The `OCID`__ of the VCN the NAT gateway
        belongs to.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this NatGateway.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def public_ip_id(self):
        """
        Gets the public_ip_id of this NatGateway.
        The `OCID`__ of the public IP address associated with the NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The public_ip_id of this NatGateway.
        :rtype: str
        """
        return self._public_ip_id

    @public_ip_id.setter
    def public_ip_id(self, public_ip_id):
        """
        Sets the public_ip_id of this NatGateway.
        The `OCID`__ of the public IP address associated with the NAT gateway.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param public_ip_id: The public_ip_id of this NatGateway.
        :type: str
        """
        self._public_ip_id = public_ip_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
